@@ -11,7 +11,7 @@ def inwd(request, wd, monkeypatch):
     if request.param == "git":
         try:
             wd("git init")
-        except FileNotFoundError:
+        except OSError:
             pytest.skip("git executable not found")
         wd("git config user.email test@example.com")
         wd('git config user.name "a test"')
@@ -20,7 +20,7 @@ def inwd(request, wd, monkeypatch):
     elif request.param == "hg":
         try:
             wd("hg init")
-        except FileNotFoundError:
+        except OSError:
             pytest.skip("hg executable not found")
         wd.add_command = "hg add ."
         wd.commit_command = 'hg commit -m test-{reason} -u test -d "0 0"'
@@ -124,6 +124,12 @@ def test_symlink_file_out_of_git(inwd):
     assert set(find_files("adir")) == _sep({"adir/filea"})
 
 
+@pytest.mark.parametrize("path_add", ["{cwd}", "{cwd}" + os.pathsep + "broken"])
+def test_ignore_root(inwd, monkeypatch, path_add):
+    monkeypatch.setenv("SETUPTOOLS_SCM_IGNORE_VCS_ROOTS", path_add.format(cwd=inwd.cwd))
+    assert find_files() == []
+
+
 def test_empty_root(inwd):
     subdir = inwd.cwd / "cdir" / "subdir"
     subdir.mkdir(parents=True)
